@@ -21,8 +21,7 @@ function(ask = TRUE)
   if (ask) {
     arg <- "*"
     while (arg %nin% c("Y", "n")) {
-      arg <- readline("Do you want to delete all objects 
-                       from the current environment? [Y/n] ")
+      arg <- readline("Delete all objects from the current environment? [Y/n] ")
     }
   } else {
     arg <- "Y"
